@@ -3,18 +3,29 @@ from __future__ import annotations
 import operator
 import warnings
 
+from typing import Any
+from typing import Callable
+from typing import ClassVar
+
 from poetry.core.constraints.generic.any_constraint import AnyConstraint
 from poetry.core.constraints.generic.base_constraint import BaseConstraint
 from poetry.core.constraints.generic.empty_constraint import EmptyConstraint
 
 
+OperatorType = Callable[[object, object], Any]
+
+
 class Constraint(BaseConstraint):
     OP_EQ = operator.eq
     OP_NE = operator.ne
 
-    _trans_op_str = {"=": OP_EQ, "==": OP_EQ, "!=": OP_NE}
+    _trans_op_str: ClassVar[dict[str, OperatorType]] = {
+        "=": OP_EQ,
+        "==": OP_EQ,
+        "!=": OP_NE,
+    }
 
-    _trans_op_int = {OP_EQ: "==", OP_NE: "!="}
+    _trans_op_int: ClassVar[dict[OperatorType, str]] = {OP_EQ: "==", OP_NE: "!="}
 
     def __init__(self, value: str, operator: str = "==") -> None:
         if operator == "=":
@@ -31,10 +42,8 @@ class Constraint(BaseConstraint):
     @property
     def version(self) -> str:
         warnings.warn(
-            (
-                "The property 'version' is deprecated and will be removed. "
-                "Please use the property 'value' instead."
-            ),
+            "The property 'version' is deprecated and will be removed. "
+            "Please use the property 'value' instead.",
             DeprecationWarning,
             stacklevel=2,
         )
@@ -84,6 +93,9 @@ class Constraint(BaseConstraint):
 
         return other.allows(self)
 
+    def invert(self) -> Constraint:
+        return Constraint(self._value, "!=" if self._operator == "==" else "==")
+
     def difference(self, other: BaseConstraint) -> Constraint | EmptyConstraint:
         if other.allows(self):
             return EmptyConstraint()
@@ -111,9 +123,9 @@ class Constraint(BaseConstraint):
         return other.intersect(self)
 
     def union(self, other: BaseConstraint) -> BaseConstraint:
-        if isinstance(other, Constraint):
-            from poetry.core.constraints.generic.union_constraint import UnionConstraint
+        from poetry.core.constraints.generic.union_constraint import UnionConstraint
 
+        if isinstance(other, Constraint):
             if other == self:
                 return self
 
@@ -128,6 +140,10 @@ class Constraint(BaseConstraint):
 
             return AnyConstraint()
 
+        # to preserve order (functionally not necessary)
+        if isinstance(other, UnionConstraint):
+            return UnionConstraint(self).union(other)
+
         return other.union(self)
 
     def is_any(self) -> bool:
